@@ -15,7 +15,7 @@ OPENGIS_PREFIX = "geo"
 LANG_STRING_TYPE = "http://www.w3.org/1999/02/22-rdf-syntax-ns#langString"
 STRING_TYPE = "http://www.w3.org/2001/XMLSchema#string"
 FLOAT_TYPE = "http://www.w3.org/2001/XMLSchema#float"
-INTEGER_TYPE = "http://www.w3.org/2001/XMLSchema#int"
+INTEGER_TYPE = "http://www.w3.org/2001/XMLSchema#integer"
 
 
 def _add_prefix(unprefixed_elem, prefix):
@@ -96,6 +96,24 @@ def parse_unquoted_literal(an_elem):
     return an_elem, elem_type
 
 
+def unprefixize_uri_if_possible(target_uri, prefix_namespaces_dict):
+    for a_prefix in prefix_namespaces_dict:
+        if target_uri.startswith(a_prefix+":"):
+            return target_uri.replace(a_prefix+":", prefix_namespaces_dict[a_prefix])
+    return target_uri
+
+
+def prefixize_uri_if_possible(target_uri, namespaces_prefix_dict):
+    best_match = None
+    candidate_uri = remove_corners(target_uri)
+    for a_namespace in namespaces_prefix_dict:  # Prefixed element (all literals are prefixed elements)
+        if candidate_uri.startswith(a_namespace):
+            if best_match is None or len(best_match) < len(a_namespace):
+                best_match = a_namespace
+
+    return target_uri if best_match is None else candidate_uri.replace(best_match, namespaces_prefix_dict[best_match] + ":")
+
+
 
 
 
